@@ -423,15 +423,25 @@ class HighResMassSpecExport(Thread):
                 # check if there is a molecular formula candidate for the msPeak
                     
                 if ms_peak:
-                    #m_formula = ms_peak.molecular_formula_lowest_error
+                    # m_formula = ms_peak.molecular_formula_lowest_error
                     for m_formula in ms_peak:
 
-                        if m_formula.is_isotopologue:  # isotopologues inline
-                            if include_isotopologues and isotopologue_inline:
-                                add_match_dict_data(index, ms_peak, m_formula)
-                        else:
-                            add_match_dict_data(index, ms_peak, m_formula)  # add monoisotopic peak
+                        if mass_spectrum.molecular_search_settings.output_score_method == "prob_score":
 
+                            if m_formula.confidence_score >= mass_spectrum.molecular_search_settings.output_min_score:
+
+                                if m_formula.is_isotopologue:  # isotopologues inline
+                                    if include_isotopologues and isotopologue_inline:
+                                        add_match_dict_data(index, ms_peak, m_formula)
+                                else:
+                                    add_match_dict_data(index, ms_peak, m_formula)  # add monoisotopic peak
+
+                        else:
+                            if m_formula.is_isotopologue:  # isotopologues inline
+                                if include_isotopologues and isotopologue_inline:
+                                    add_match_dict_data(index, ms_peak, m_formula)
+                                else:
+                                    add_match_dict_data(index, ms_peak, m_formula)  # add monoisotopic peak
                 else:
                     # include not_match
                     if include_no_match and no_match_inline:
